#!/usr/bin/python3
# Copyright 2024 Tero Karvinen https://TeroKarvinen.com

# sudo apt-get install python3-django
# django-admin --version # prints "3.2.19"

from datetime import datetime
from dateutil.relativedelta import relativedelta

from django.template import Template, Context
from django.conf import settings
import django

## Set up Single file Django

settings.configure(TEMPLATES=[
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'APP_DIRS': False, # we have no apps
    },
])
django.setup()

## Print dates

start = datetime(1700, 1, 1)
# end = datetime(1700, 1, 18)
end = datetime(2400, 1, 1)

day = start

while day <= end:
	# https://docs.djangoproject.com/en/3.2/ref/templates/builtins/#date picks, dashes added, reordered """
	# - Uses a similar format to PHP’s date() function with some differences.
	# - o ISO-8601 week-numbering year, corresponding to the ISO-8601 week number (W) which uses leap weeks. See Y for the more common year format. '1999'
	# - W SO-8601 week number of year, with weeks starting on Monday. 1, 53
	# """
	# Not the same as in PHP. This works in PHP "Y-m-d \wW D", but lacks week zero padding in Django.
	# It seems that Django template filter "date" does not have a zero padded week number as of 2024-01-04 w01 Thu.
	# To get zero padded ISO week number, 'day | date:"W"' prints week number as a string without padding "2",
	# which is then converted to integer '| add:"0"' and padded with leading zero 'stringformat:"02d"'
	# "Y" seems to be the correct year for ISO8601 dates. The suggested "o" gives nonsensical results.
	t = Template('{{ day | date:"Y-m-d" }} w{{ day | date:"W" | add:"0" | stringformat:"02d"}} {{ day | date:"D" }}') 
	c = Context({'day': day})
	s = t.render(c)
	print(s)

	day += relativedelta(days=+1)

